summaryrefslogtreecommitdiffstats
path: root/base/atomicops_internals_x86_gcc.h
diff options
context:
space:
mode:
Diffstat (limited to 'base/atomicops_internals_x86_gcc.h')
-rw-r--r--base/atomicops_internals_x86_gcc.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/base/atomicops_internals_x86_gcc.h b/base/atomicops_internals_x86_gcc.h
index 297727e..72fd350 100644
--- a/base/atomicops_internals_x86_gcc.h
+++ b/base/atomicops_internals_x86_gcc.h
@@ -8,10 +8,10 @@
#define BASE_ATOMICOPS_INTERNALS_X86_GCC_H_
#pragma once
-#include "base/base_api.h"
+#include "base/base_export.h"
// This struct is not part of the public API of this module; clients may not
// use it. (However, it's exported via BASE_API because clients implicitly
// do use it at link time by inlining these functions.)
// Features of this x86. Values may not be correct before main() is run,
// but are set conservatively.
@@ -20,7 +20,7 @@ struct AtomicOps_x86CPUFeatureStruct {
// after acquire compare-and-swap.
bool has_sse2; // Processor has SSE2.
};
-BASE_API extern struct AtomicOps_x86CPUFeatureStruct
+BASE_EXPORT extern struct AtomicOps_x86CPUFeatureStruct
AtomicOps_Internalx86CPUFeatures;
#define ATOMICOPS_COMPILER_BARRIER() __asm__ __volatile__("" : : : "memory")
@@ -8,10 +8,10 @@
// This struct is not part of the public API of this module; clients may not
-// use it. (However, it's exported via BASE_API because clients implicitly
+// use it. (However, it's exported via BASE_EXPORT because clients implicitly
// do use it at link time by inlining these functions.)
// Features of this x86. Values may not be correct before main() is run,